# FileTemplateParameterName

A name for a file template parameter. The system provides a few well-known values:  - \"user.id\"  - \"user.email\"  - \"user.first_name\"  - \"user.last_name\"  - \"user.full_name\" 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **str** | A name for a file template parameter. The system provides a few well-known values:  - \&quot;user.id\&quot;  - \&quot;user.email\&quot;  - \&quot;user.first_name\&quot;  - \&quot;user.last_name\&quot;  - \&quot;user.full_name\&quot;  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


